MChannelStats class

Channel stats model

Constructors

MChannelStats({required String channelId, required int memberCount, required int guestCount, required int pinnedPostCount})
MChannelStats.fromJson(Map<String, dynamic> json)
factory

Properties

channelId String
final
guestCount int
final
hashCode int
The hash code for this object.
no setterinherited
memberCount int
final
pinnedPostCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited