MCommandAttachment class

Command attachment model

Constructors

MCommandAttachment({required String id, required String fallback, String? color, String? pretext, String? authorName, String? authorLink, String? authorIcon, String? title, String? titleLink, String? text, List<MCommandAttachmentField>? fields, String? imageUrl, String? thumbUrl, String? footer, String? footerIcon, dynamic timestamp})
MCommandAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

authorIcon String?
final
final
authorName String?
final
color String?
final
fallback String
final
fields List<MCommandAttachmentField>?
final
final
footerIcon String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
imageUrl String?
final
pretext String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
thumbUrl String?
final
timestamp → dynamic
final
title String?
final
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited