MSharedChannel class

Shared channel model

Constructors

MSharedChannel({required String id, required String teamId, required String home, required String displayName, required String name, required String purpose, required String header, int? createAt, int? updateAt, int? deleteAt, String? creatorId, String? remoteId})
MSharedChannel.fromJson(Map<String, dynamic> json)
factory

Properties

createAt int?
final
creatorId String?
final
deleteAt int?
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
final
home String
final
id String
final
name String
final
purpose String
final
remoteId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamId String
final
updateAt int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited