MUserNotifyProps class

Constructors

MUserNotifyProps({String email = 'true', String push = 'mention', String desktop = 'all', String desktopSound = 'true', String mentionKeys = '', String channel = 'true', String firstName = 'true'})
MUserNotifyProps.fromJson(Map<String, dynamic> json)
factory

Properties

channel String
Set to "true" to enable channel-wide notifications (@channel, @all, etc.), "false" to disable. Defaults to "true".
final
desktop String
Set to "all" to receive desktop notifications for all activity, "mention" for mentions and direct messages only, and "none" to disable. Defaults to "all".
final
desktopSound String
Set to "true" to enable sound on desktop notifications, "false" to disable. Defaults to "true".
final
email String
Set to "true" to enable email notifications, "false" to disable. Defaults to "true".
final
firstName String
Set to "true" to enable mentions for first name. Defaults to "true" if a first name is set, "false" otherwise.
final
hashCode int
The hash code for this object.
no setterinherited
mentionKeys String
A comma-separated list of words to count as mentions. Defaults to username and @username.
final
push String
Set to "all" to receive push notifications for all activity, "mention" for mentions and direct messages only, and "none" to disable. Defaults to "mention".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited