MCommandsApi class
API for command-related endpoints
Constructors
- MCommandsApi(Dio _dio)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCommand(
{required String teamId, required String trigger, required String method, required String username, required String displayName, required String description, required String url, String? iconUrl, bool? autoComplete, String? autoCompleteDesc, String? autoCompleteHint}) → Future< MCommand> - Create a command
-
deleteCommand(
String commandId) → Future< void> - Delete a command
-
executeCommand(
{required String channelId, required String command, String? teamId}) → Future< MCommandResponse> - Execute a command
-
getCommand(
String commandId) → Future< MCommand> - Get a command
-
getCommands(
{String? teamId, bool? customOnly}) → Future< List< MCommand> > - Get all commands
-
listAutocompleteCommands(
String teamId) → Future< List< MCommand> > - List autocomplete commands
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
regenerateCommandToken(
String commandId) → Future< Map< String, String> > - Regenerate command token
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCommand(
String commandId, {String? trigger, String? method, String? username, String? displayName, String? description, String? url, String? iconUrl, bool? autoComplete, String? autoCompleteDesc, String? autoCompleteHint}) → Future< MCommand> - Update a command
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited