MFileInfo class
File info model
Constructors
- MFileInfo({required String id, required String userId, required String postId, required String name, required String extension, required int size, required String mimeType, required int width, required int height, required bool hasPreviewImage, int? createAt, int? updateAt, int? deleteAt})
-
MFileInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createAt → int?
-
final
- deleteAt → int?
-
final
- extension → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPreviewImage → bool
-
final
- height → int
-
final
- id → String
-
final
- mimeType → String
-
final
- name → String
-
final
- postId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- updateAt → int?
-
final
- userId → String
-
final
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited